# Google UI

Google UI is an open-source UI library for developing cross-platform apps using Flutter with "Material Design 2.0"

## Table of contents

- [Installation](#instalation)
  - [Setup font](#setup-font)
  - [Install Google UI](#install-google-ui)
- [Widgets](#widgets)
  - [Button](#button)
  - [ListTile](#listtile)
    - [ListTile](#glisttile)
    - [GDrawerListTile](#gdrawerlisttile)
    - [SwitchListTile](#gswitch)
    - [RadioListTile](#gradio)
    - [CheckBoxListTile](#gcheckbox)
  - [GSelectBox](#gselectbox)
  - [AppBar](#gappbar)
  - [Form field](#field)
  - [GErrorMessage](#gerrormessage)
  - [Grid](#grid)
  - [Text](#gtext)

## Installation

### Setup font

Google UI uses poppins font family as an alternative to product sans

- Download the [font](https://fonts.google.com/share?selection.family=Poppins:ital,wght@0,300;0,400;0,500;1,300;1,400;1,500)
- Import font to pubspec.yaml

```yaml
fonts:
  - family: Poppins
    fonts:
      - asset: fonts/Poppins/Poppins-Light.ttf
      - asset: fonts/Poppins/Poppins-LightItalic.ttf
        weight: 300
      - asset: fonts/Poppins/Poppins-Regular.ttf
      - asset: fonts/Poppins/Poppins-Italic.ttf
        weight: 400
      - asset: fonts/Poppins/Poppins-Medium.ttf
      - asset: fonts/Poppins/Poppins-MediumItalic.ttf
        weight: 500
```

### Install Google UI

- Follow instalation instruction [here](https://pub.dev/packages/google_ui/install)

- Initialize Google UI

```dart
return GoogleUI(
  builder: (context, theme, darkTheme) {
    return MaterialApp(
      title: "YOUR APP NAME",
      theme: theme,
      darkTheme: darkTheme,
      home: const HomePage(),
    );
  },
),
```

## Widgets

## Button

![](./screenshots/button.jpg)

## ListTile

### ListTile

![](./screenshots/list_tile.jpg)

### GDrawerListTile

![](./screenshots/drawer_list_tile.jpg)

```dart
GDrawerListTile(
  leading: const Icon(Icons.inbox_outlined),
  title: "Inbox",
  trailing: const Text("1"),
  selected: true,
  onTap: () {},
),
```

### SwitchListTile

![](./screenshots/switch.jpg)

### RadioListTile

![](./screenshots/radio.jpg)

### CheckBoxListTile

![](./screenshots/check_box.jpg)

## GSelectBox

![](./screenshots/select_box.jpg)

```dart
GSelectBox<int>(
  value: value,
  items: [
    GSelectBoxItem(
      title: "Select 1",
      value: 1,
    ),
    GSelectBoxItem(
      title: "Select 2",
      value: 2,
    ),
    GSelectBoxItem(
      title: "Select 3",
      value: 3,
    ),
  ],
  onChanged: (value) {},
),
```

## AppBar

![](./screenshots/app_bar.jpg)

## Field

![](./screenshots/field.jpg)

## GErrorMessage

![](./screenshots/error_message.jpg)

```dart
GErrorMessage(
  icon: const Icon(Icons.wifi_off_outlined),
  title: "No internet",
  subtitle:
      "Can't connect to the internet.\nPlease check your internet connection",
  buttonLabel: "Try again"
  onPressed: () {},
),
```

## Grid

![](./screenshots/grid.jpg)

```dart
GGrid(
  gap: 16,
  padding: EdgeInsets.all(16),
  columnCount: 3,
  children: [],
)
```

## Text

![](./screenshots/text.jpg)