import 'package:flutter/material.dart';

import '../utils/color_util.dart';

class GPaletteData {
  final MaterialColor primary;
  final MaterialColor secondary;
  final MaterialColor tersiary;
  final MaterialColor error;
  final MaterialColor surface;
  final MaterialColor background;
  final MaterialColor onPrimary;
  final MaterialColor onSecondary;
  final MaterialColor onTersiary;
  final MaterialColor onError;
  final MaterialColor onSurface;
  final MaterialColor onBackground;
  final MaterialColor gray;
  final MaterialColor red;
  final MaterialColor orange;
  final MaterialColor yellow;
  final MaterialColor green;
  final MaterialColor blue;
  final MaterialColor indigo;
  final MaterialColor pink;
  final MaterialColor black;
  final MaterialColor white;
  final Brightness brightness;

  const GPaletteData({
    required this.primary,
    required this.secondary,
    required this.tersiary,
    required this.error,
    required this.surface,
    required this.background,
    required this.onPrimary,
    required this.onSecondary,
    required this.onTersiary,
    required this.onError,
    required this.onSurface,
    required this.onBackground,
    required this.gray,
    required this.red,
    required this.orange,
    required this.yellow,
    required this.green,
    required this.blue,
    required this.indigo,
    required this.pink,
    required this.black,
    required this.white,
    required this.brightness,
  });

  GPaletteData copyWith({
    MaterialColor? primary,
    MaterialColor? secondary,
    MaterialColor? tersiary,
    MaterialColor? error,
    MaterialColor? surface,
    MaterialColor? background,
    MaterialColor? onPrimary,
    MaterialColor? onSecondary,
    MaterialColor? onTersiary,
    MaterialColor? onError,
    MaterialColor? onSurface,
    MaterialColor? onBackground,
    MaterialColor? gray,
    MaterialColor? red,
    MaterialColor? orange,
    MaterialColor? yellow,
    MaterialColor? green,
    MaterialColor? blue,
    MaterialColor? indigo,
    MaterialColor? pink,
    MaterialColor? black,
    MaterialColor? white,
    Brightness? brightness,
  }) {
    return GPaletteData(
      primary: primary ?? this.primary,
      secondary: secondary ?? this.secondary,
      tersiary: tersiary ?? this.tersiary,
      error: error ?? this.error,
      surface: surface ?? this.surface,
      background: background ?? this.background,
      onPrimary: onPrimary ?? this.onPrimary,
      onSecondary: onSecondary ?? this.onSecondary,
      onTersiary: onTersiary ?? this.onTersiary,
      onError: onError ?? this.onError,
      onSurface: onSurface ?? this.onSurface,
      onBackground: onBackground ?? this.onBackground,
      gray: gray ?? this.gray,
      red: red ?? this.red,
      orange: orange ?? this.orange,
      yellow: yellow ?? this.yellow,
      green: green ?? this.green,
      blue: blue ?? this.blue,
      indigo: indigo ?? this.indigo,
      pink: pink ?? this.pink,
      black: pink ?? this.black,
      white: pink ?? this.white,
      brightness: brightness ?? this.brightness,
    );
  }

  ColorScheme toColorScheme() {
    return ColorScheme(
      primary: primary,
      primaryContainer: primary,
      secondary: primary,
      secondaryContainer: primary,
      surface: surface,
      background: background,
      error: error,
      onPrimary: onPrimary,
      onSecondary: onSecondary,
      onSurface: onSurface,
      onBackground: onBackground,
      onError: onError,
      brightness: brightness,
    );
  }

  static final kLightPalette = GPaletteData(
    primary: ColorUtil.createMaterialColor(const Color(0xFF0078d7)),
    secondary: ColorUtil.createMaterialColor(const Color(0xFF0078d7)),
    tersiary: ColorUtil.createMaterialColor(const Color(0xFF0078d7)),
    error: ColorUtil.createMaterialColor(const Color(0xFFc62828)),
    surface: ColorUtil.createMaterialColor(Colors.white),
    background: ColorUtil.createMaterialColor(Colors.white),
    onPrimary: ColorUtil.createMaterialColor(Colors.white),
    onSecondary: ColorUtil.createMaterialColor(Colors.white),
    onTersiary: ColorUtil.createMaterialColor(Colors.white),
    onError: ColorUtil.createMaterialColor(Colors.white),
    onSurface: ColorUtil.createMaterialColor(const Color(0xFF323130)),
    onBackground: ColorUtil.createMaterialColor(const Color(0xFF323130)),
    gray: ColorUtil.createMaterialColor(const Color(0XFF9E9E9E)),
    red: ColorUtil.createMaterialColor(const Color(0XFFF44336)),
    orange: ColorUtil.createMaterialColor(const Color(0XFFFF9800)),
    yellow: ColorUtil.createMaterialColor(const Color(0XFFFFEB3B)),
    green: ColorUtil.createMaterialColor(const Color(0XFF4CAF50)),
    blue: ColorUtil.createMaterialColor(const Color(0XFF2196F3)),
    indigo: ColorUtil.createMaterialColor(const Color(0XFF3F51B5)),
    pink: ColorUtil.createMaterialColor(const Color(0XFFE91E63)),
    black: ColorUtil.createMaterialColor(Colors.black),
    white: ColorUtil.createMaterialColor(Colors.white),
    brightness: Brightness.light,
  );

  static final kDarkPalette = GPaletteData(
    primary: ColorUtil.createMaterialColor(const Color(0xFF80BCEB)),
    secondary: ColorUtil.createMaterialColor(const Color(0xFF80BCEB)),
    tersiary: ColorUtil.createMaterialColor(const Color(0xFF80BCEB)),
    error: ColorUtil.createMaterialColor(const Color(0XFFEF9A9A)),
    surface: ColorUtil.createMaterialColor(const Color(0XFF1C1D22)),
    background: ColorUtil.createMaterialColor(const Color(0XFF1C1D22)),
    onPrimary: ColorUtil.createMaterialColor(const Color(0XFF323130)),
    onSecondary: ColorUtil.createMaterialColor(const Color(0XFF323130)),
    onTersiary: ColorUtil.createMaterialColor(const Color(0XFF323130)),
    onError: ColorUtil.createMaterialColor(const Color(0XFF323130)),
    onSurface: ColorUtil.createMaterialColor(Colors.white),
    onBackground: ColorUtil.createMaterialColor(Colors.white),
    gray: ColorUtil.createMaterialColor(const Color(0XFFEEEEEE)),
    red: ColorUtil.createMaterialColor(const Color(0XFFEF9A9A)),
    orange: ColorUtil.createMaterialColor(const Color(0XFFFFE0B2)),
    yellow: ColorUtil.createMaterialColor(const Color(0XFFFFF9C4)),
    green: ColorUtil.createMaterialColor(const Color(0XFFC8E6C9)),
    blue: ColorUtil.createMaterialColor(const Color(0XFFBBDEFB)),
    indigo: ColorUtil.createMaterialColor(const Color(0XFFC5CAE9)),
    pink: ColorUtil.createMaterialColor(const Color(0XFFF8BBD0)),
    black: ColorUtil.createMaterialColor(Colors.black),
    white: ColorUtil.createMaterialColor(Colors.white),
    brightness: Brightness.dark,
  );
}
