import 'package:flutter/material.dart';

/// Material dialog utilities class.
class DialogUtil {
  /// Show loading indicator dialog.
  static Future<void> showLoadingDialog({
    required BuildContext context,
    Color? primaryColor,
  }) {
    return showDialog(
      context: context,
      barrierDismissible: false,
      builder: (contex) => WillPopScope(
        onWillPop: () async => false,
        child: Center(child: CircularProgressIndicator(color: primaryColor)),
      ),
    );
  }

  /// Show alert dialog, often used to show confirmation or alert dialog.
  static Future<void> showAlertDialog({
    required BuildContext context,
    required String title,
    required String message,
    required String confirmLabel,
    String? cancelLabel,
    void Function()? onConfirm,
    void Function()? onCancel,
  }) {
    return showDialog(
      context: context,
      builder: (contex) => _AlertDialog(
        title: title,
        message: message,
        confirmLabel: confirmLabel,
        cancelLabel: cancelLabel,
        onConfirm: onConfirm,
        onCancel: onCancel,
      ),
    );
  }
}

class _AlertDialog extends StatelessWidget {
  const _AlertDialog({
    Key? key,
    required this.title,
    required this.message,
    required this.confirmLabel,
    this.cancelLabel,
    required this.onConfirm,
    required this.onCancel,
  }) : super(key: key);

  final String title;
  final String message;
  final String confirmLabel;
  final String? cancelLabel;
  final void Function()? onConfirm;
  final void Function()? onCancel;

  @override
  Widget build(BuildContext context) {
    void onCancelPressed() {
      Navigator.of(context).pop();
      onCancel?.call();
    }

    void onConfirmPressed() {
      Navigator.of(context).pop();
      onConfirm?.call();
    }

    return AlertDialog(
      title: Text(title),
      content: Text(message),
      actions: [
        if (cancelLabel != null)
          TextButton(onPressed: onCancelPressed, child: Text(cancelLabel!)),
        TextButton(onPressed: onConfirmPressed, child: Text(confirmLabel)),
      ],
    );
  }
}
