import 'package:flutter/material.dart';

import '../theme/g_palette.dart';

/// Create a error message,
/// usually displayed on the page when an error occurs
/// such as no internet error, not found error, and others.
class GErrorMessage extends StatelessWidget {
  const GErrorMessage({
    Key? key,
    required this.icon,
    required this.title,
    this.subtitle,
    required this.buttonLabel,
    this.onPressed,
  }) : super(key: key);

  /// An icon to display.
  final Widget icon;

  /// An error title.
  final String title;

  /// A description to explain the error
  final String? subtitle;

  /// Text that describes the button.
  final String buttonLabel;

  /// A callback after the user click the button.
  final void Function()? onPressed;

  @override
  Widget build(BuildContext context) {
    final textTheme = Theme.of(context).textTheme;
    final palette = GPalette.of(context);

    return Center(
      child: SizedBox(
        width: double.infinity,
        child: Column(
          mainAxisAlignment: MainAxisAlignment.center,
          children: [
            Container(
              padding: const EdgeInsets.all(16),
              decoration: BoxDecoration(
                shape: BoxShape.circle,
                color: palette.primary.withOpacity(.1),
              ),
              child: Theme(
                data: Theme.of(context).copyWith(
                  iconTheme: IconThemeData(size: 40, color: palette.primary),
                ),
                child: icon,
              ),
            ),
            const SizedBox(height: 16),
            Text(title, style: textTheme.bodyText1),
            if (subtitle != null) ...[
              const SizedBox(height: 16),
              Text(
                subtitle!,
                style: TextStyle(color: palette.onBackground.withOpacity(.75)),
                textAlign: TextAlign.center,
              ),
            ],
            if (onPressed != null) const SizedBox(height: 32),
            if (onPressed != null)
              ElevatedButton(
                onPressed: onPressed,
                child: Text(buttonLabel),
              ),
          ],
        ),
      ),
    );
  }
}
