import 'package:flutter/material.dart';

import '../theme/index.dart';

/// Create a section title.
class GSectionTitle extends StatelessWidget {
  const GSectionTitle(
    this.title, {
    Key? key,
    this.padding,
    this.color,
    this.backgroundColor,
  }) : super(key: key);

  /// Text that describes the section.
  final String title;

  /// An empty space.
  /// If null, `EdgeInsets.fromLTRB(16, 24, 16, 8)` is used.
  final EdgeInsets? padding;

  /// Set [title] text color.
  final Color? color;

  /// Set [GSectionTitle] background color.
  final Color? backgroundColor;

  @override
  Widget build(BuildContext context) {
    final palette = GPalette.of(context);
    final sectionTitleTheme = GSectionTitleTheme.of(context);

    final textColor = color ?? sectionTitleTheme?.color ?? palette.primary;
    final backgroundColor =
        this.backgroundColor ?? sectionTitleTheme?.backgroundColor;

    return Container(
      width: double.infinity,
      color: backgroundColor,
      padding: padding ?? sectionTitleTheme?.padding,
      child: Text(
        title,
        style: TextStyle(color: textColor, fontWeight: FontWeight.w600),
      ),
    );
  }
}
